pub struct Parsed<'a> {
pub entries: Vec<Entry<'a>>,
pub skipped: Vec<usize>,
}Expand description
The result of a parse: the entries in file order plus the line numbers that were skipped.
Fields
entries: Vec<Entry<'a>>The pairs that parsed, in file order.
skipped: Vec<usize>Line numbers, counted from 1, that were neither a pair nor a comment or blank.